==> svix-0.84.0.tar.gz: svix-0.84.0/svix/internal/openapi_client/api/statistics/calculate_aggregate_app_stats.py <==
import random
from time import sleep
from typing import Any, Dict, Union

import httpx

from ...client import Client
from ...models.background_task_out_common import BackgroundTaskOutCommon
from ...models.calculate_app_stats_in import CalculateAppStatsIn
from ...models.http_error import HttpError
from ...models.http_validation_error import HTTPValidationError
from ...types import UNSET, Unset


def _get_kwargs(
    *,
    client: Client,
    json_body: CalculateAppStatsIn,
    idempotency_key: Union[Unset, str] = UNSET,
) -> Dict[str, Any]:
    url = "{}/api/v1/stats/usage/app/".format(client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    if not isinstance(idempotency_key, Unset):
        headers["idempotency-key"] = idempotency_key

    json_json_body = json_body.to_dict()

    return {
        "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(*, response: httpx.Response) -> BackgroundTaskOutCommon:
    if response.status_code == 401:
        raise HttpError(response.json(), response.status_code)
    if response.status_code == 403:
        raise HttpError(response.json(), response.status_code)
    if response.status_code == 404:
        raise HttpError(response.json(), response.status_code)
    if response.status_code == 409:
        raise HttpError(response.json(), response.status_code)
    if response.status_code == 422:
        raise HTTPValidationError(response.json(), response.status_code)
    if response.status_code == 429:
        raise HttpError(response.json(), response.status_code)
    response_202 = BackgroundTaskOutCommon.from_dict(response.json())

    return response_202


sleep_time = 0.05
num_retries = 3


def sync_detailed(
    *,
    client: Client,
    json_body: CalculateAppStatsIn,
    idempotency_key: Union[Unset, str] = UNSET,
) -> BackgroundTaskOutCommon:
    """Calculate Aggregate App Stats

     Creates a background task to calculate the message destinations for all applications in the
    environment.

    Args:
        idempotency_key (Union[Unset, str]):
        json_body (CalculateAppStatsIn):

    Returns:
        BackgroundTaskOutCommon
    """

    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
        idempotency_key=idempotency_key,
    )

    kwargs["headers"] = {"svix-req-id": f"{random.getrandbits(32)}", **kwargs["headers"]}

    retry_count = 0
    for retry in range(num_retries):
        response = httpx.request(
            verify=client.verify_ssl,
            **kwargs,
        )
        if response.status_code >= 500 and retry < num_retries:
            retry_count += 1
            kwargs["headers"]["svix-retry-count"] = str(retry_count)
            sleep(sleep_time)
            sleep_time * 2
        else:
            break

    return _parse_response(response=response)


def sync(
    *,
    client: Client,
    json_body: CalculateAppStatsIn,
    idempotency_key: Union[Unset, str] = UNSET,
) -> BackgroundTaskOutCommon:
    """Calculate Aggregate App Stats

     Creates a background task to calculate the message destinations for all applications in the
    environment.

    Args:
        idempotency_key (Union[Unset, str]):
        json_body (CalculateAppStatsIn):

    Returns:
        BackgroundTaskOutCommon
    """

    return sync_detailed(
        client=client,
        json_body=json_body,
        idempotency_key=idempotency_key,
    )


async def asyncio_detailed(
    *,
    client: Client,
    json_body: CalculateAppStatsIn,
    idempotency_key: Union[Unset, str] = UNSET,
) -> BackgroundTaskOutCommon:
    """Calculate Aggregate App Stats

     Creates a background task to calculate the message destinations for all applications in the
    environment.

    Args:
        idempotency_key (Union[Unset, str]):
        json_body (CalculateAppStatsIn):

    Returns:
        BackgroundTaskOutCommon
    """

    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
        idempotency_key=idempotency_key,
    )

    kwargs["headers"] = {"svix-req-id": f"{random.getrandbits(32)}", **kwargs["headers"]}

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        retry_count = 0
        for retry in range(num_retries):
            response = await _client.request(**kwargs)
            if response.status_code >= 500 and retry < num_retries:
                retry_count += 1
                kwargs["headers"]["svix-retry-count"] = str(retry_count)
                sleep(sleep_time)
                sleep_time * 2
            else:
                break

    return _parse_response(response=response)


async def asyncio(
    *,
    client: Client,
    json_body: CalculateAppStatsIn,
    idempotency_key: Union[Unset, str] = UNSET,
) -> BackgroundTaskOutCommon:
    """Calculate Aggregate App Stats

     Creates a background task to calculate the message destinations for all applications in the
    environment.

    Args:
        idempotency_key (Union[Unset, str]):
        json_body (CalculateAppStatsIn):

    Returns:
        BackgroundTaskOutCommon
    """

    return await asyncio_detailed(
        client=client,
        json_body=json_body,
        idempotency_key=idempotency_key,
    )

==> svix-0.84.1.tar.gz: svix-0.84.1/svix/internal/openapi_client/api/statistics/calculate_aggregate_app_stats.py <==
import random
from time import sleep
from typing import Any, Dict, Union

import httpx

from ...client import AuthenticatedClient
from ...models.app_usage_stats_in import AppUsageStatsIn
from ...models.app_usage_stats_out import AppUsageStatsOut
from ...models.http_error import HttpError
from ...models.http_validation_error import HTTPValidationError
from ...types import UNSET, Unset


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    json_body: AppUsageStatsIn,
    idempotency_key: Union[Unset, str] = UNSET,
) -> Dict[str, Any]:
    url = "{}/api/v1/stats/usage/app/".format(client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    if not isinstance(idempotency_key, Unset):
        headers["idempotency-key"] = idempotency_key

    json_json_body = json_body.to_dict()

    return {
        "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(*, response: httpx.Response) -> AppUsageStatsOut:
    if response.status_code == 401:
        raise HttpError(response.json(), response.status_code)
    if response.status_code == 403:
        raise HttpError(response.json(), response.status_code)
    if response.status_code == 404:
        raise HttpError(response.json(), response.status_code)
    if response.status_code == 409:
        raise HttpError(response.json(), response.status_code)
    if response.status_code == 422:
        raise HTTPValidationError(response.json(), response.status_code)
    if response.status_code == 429:
        raise HttpError(response.json(), response.status_code)
    response_202 = AppUsageStatsOut.from_dict(response.json())

    return response_202


sleep_time = 0.05
num_retries = 3


def sync_detailed(
    *,
    client: AuthenticatedClient,
    json_body: AppUsageStatsIn,
    idempotency_key: Union[Unset, str] = UNSET,
) -> AppUsageStatsOut:
    """Calculate Aggregate App Stats

     Creates a background task to calculate the message destinations for all applications in the
    environment.

    Args:
        idempotency_key (Union[Unset, str]):
        json_body (AppUsageStatsIn):

    Returns:
        AppUsageStatsOut
    """

    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
        idempotency_key=idempotency_key,
    )

    kwargs["headers"] = {"svix-req-id": f"{random.getrandbits(32)}", **kwargs["headers"]}

    retry_count = 0
    for retry in range(num_retries):
        response = httpx.request(
            verify=client.verify_ssl,
            **kwargs,
        )
        if response.status_code >= 500 and retry < num_retries:
            retry_count += 1
            kwargs["headers"]["svix-retry-count"] = str(retry_count)
            sleep(sleep_time)
            sleep_time * 2
        else:
            break

    return _parse_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    json_body: AppUsageStatsIn,
    idempotency_key: Union[Unset, str] = UNSET,
) -> AppUsageStatsOut:
    """Calculate Aggregate App Stats

     Creates a background task to calculate the message destinations for all applications in the
    environment.

    Args:
        idempotency_key (Union[Unset, str]):
        json_body (AppUsageStatsIn):

    Returns:
        AppUsageStatsOut
    """

    return sync_detailed(
        client=client,
        json_body=json_body,
        idempotency_key=idempotency_key,
    )


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    json_body: AppUsageStatsIn,
    idempotency_key: Union[Unset, str] = UNSET,
) -> AppUsageStatsOut:
    """Calculate Aggregate App Stats

     Creates a background task to calculate the message destinations for all applications in the
    environment.

    Args:
        idempotency_key (Union[Unset, str]):
        json_body (AppUsageStatsIn):

    Returns:
        AppUsageStatsOut
    """

    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
        idempotency_key=idempotency_key,
    )

    kwargs["headers"] = {"svix-req-id": f"{random.getrandbits(32)}", **kwargs["headers"]}

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        retry_count = 0
        for retry in range(num_retries):
            response = await _client.request(**kwargs)
            if response.status_code >= 500 and retry < num_retries:
                retry_count += 1
                kwargs["headers"]["svix-retry-count"] = str(retry_count)
                sleep(sleep_time)
                sleep_time * 2
            else:
                break

    return _parse_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    json_body: AppUsageStatsIn,
    idempotency_key: Union[Unset, str] = UNSET,
) -> AppUsageStatsOut:
    """Calculate Aggregate App Stats

     Creates a background task to calculate the message destinations for all applications in the
    environment.

    Args:
        idempotency_key (Union[Unset, str]):
        json_body (AppUsageStatsIn):

    Returns:
        AppUsageStatsOut
    """

    return await asyncio_detailed(
        client=client,
        json_body=json_body,
        idempotency_key=idempotency_key,
    )
